coef.cv.l0ara: Extract coefficients from a '"cv.l0ara"' object

View source: R/summary.R

coef.cv.l0araR Documentation

Extract coefficients from a "cv.l0ara" object

Description

Return coefficients from the model refit at the selected lam.min.

Usage

## S3 method for class 'cv.l0ara'
coef(object, ...)

Arguments

object

Fitted "cv.l0ara" object.

...

Not used argument.

Details

If object$fit.min is missing, the model is refit on the full data using lam.min.

Value

A named numeric vector of fitted coefficients.

Author(s)

Wenchuan Guo <wguo1017@gmail.com>, Shujie Ma <shujie.ma@ucr.edu>, Zhenqiu Liu <Zhenqiu.Liu@cshs.org>

See Also

predict.l0ara, l0ara, cv.l0ara.


l0ara documentation built on April 27, 2026, 9:08 a.m.