plot.cv.l0ara: Plot a '"cv.l0ara"' object

View source: R/summary.R

plot.cv.l0araR Documentation

Plot a "cv.l0ara" object

Description

Plot the cross-validation scores against the supplied penalty values and mark the selected lam.min.

Usage

## S3 method for class 'cv.l0ara'
plot(x, col = 3, ...)

Arguments

x

Fitted "cv.l0ara" object.

col

Color used for the plotted points.

...

Not used argument.

Value

Called for its side effect of producing a plot.

Author(s)

Wenchuan Guo <wguo1017@gmail.com>, Shujie Ma <shujie.ma@ucr.edu>, Zhenqiu Liu <Zhenqiu.Liu@cshs.org>

See Also

coef.cv.l0ara, cv.l0ara, l0ara.


l0ara documentation built on April 27, 2026, 9:08 a.m.