plot.l0ara: Plot a '"l0ara"' object

View source: R/summary.R

plot.l0araR Documentation

Plot a "l0ara" object

Description

Plot fitted values against the linear predictor and, for logistic models, optionally add an ROC curve based on in-sample fitted probabilities.

Usage

## S3 method for class 'l0ara'
plot(x, auc = FALSE, split = FALSE, col = 4, ...)

Arguments

x

Fitted "l0ara" object.

auc

Logical; if TRUE and x$family == "logit", also draw an ROC curve.

split

Logical; if TRUE, do not change the graphics layout with par(mfrow = ...).

col

Color used for observed points and the ROC line.

...

Not used argument.

Value

Called for its side effect of producing one or two plots.

Author(s)

Wenchuan Guo <wguo1017@gmail.com>, Shujie Ma <shujie.ma@ucr.edu>, Zhenqiu Liu <Zhenqiu.Liu@cshs.org>

See Also

predict.l0ara, coef.l0ara, l0ara.


l0ara documentation built on April 27, 2026, 9:08 a.m.