| coef.cv.l0ara | R Documentation |
"cv.l0ara" objectReturn coefficients from the model refit at the selected
lam.min.
## S3 method for class 'cv.l0ara'
coef(object, ...)
object |
Fitted "cv.l0ara" object. |
... |
Not used argument. |
If object$fit.min is missing, the model is refit on the full
data using lam.min.
A named numeric vector of fitted coefficients.
Wenchuan Guo <wguo1017@gmail.com>, Shujie Ma <shujie.ma@ucr.edu>, Zhenqiu Liu <Zhenqiu.Liu@cshs.org>
predict.l0ara, l0ara,
cv.l0ara.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.