| plot.l0ara | R Documentation |
"l0ara" objectPlot fitted values against the linear predictor and, for logistic models, optionally add an ROC curve based on in-sample fitted probabilities.
## S3 method for class 'l0ara'
plot(x, auc = FALSE, split = FALSE, col = 4, ...)
x |
Fitted "l0ara" object. |
auc |
Logical; if |
split |
Logical; if |
col |
Color used for observed points and the ROC line. |
... |
Not used argument. |
Called for its side effect of producing one or two plots.
Wenchuan Guo <wguo1017@gmail.com>, Shujie Ma <shujie.ma@ucr.edu>, Zhenqiu Liu <Zhenqiu.Liu@cshs.org>
predict.l0ara, coef.l0ara,
l0ara.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.